aboutsummaryrefslogtreecommitdiff
path: root/src/errors/async_di_container.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/errors/async_di_container.rs')
-rw-r--r--src/errors/async_di_container.rs13
1 files changed, 11 insertions, 2 deletions
diff --git a/src/errors/async_di_container.rs b/src/errors/async_di_container.rs
index bdb6fa0..22d8fdd 100644
--- a/src/errors/async_di_container.rs
+++ b/src/errors/async_di_container.rs
@@ -15,8 +15,17 @@ use crate::errors::injectable::InjectableError;
pub enum AsyncDIContainerError
{
/// Unable to cast a binding for a interface.
- #[error("Unable to cast binding for interface '{0}'")]
- CastFailed(&'static str),
+ #[error(
+ "Unable to cast binding for interface '{interface} with kind '{binding_kind}'"
+ )]
+ CastFailed
+ {
+ /// The interface.
+ interface: &'static str,
+
+ /// The kind of the found binding.
+ binding_kind: &'static str,
+ },
/// Failed to resolve a binding for a interface.
#[error("Failed to resolve binding for interface '{interface}'")]